<?php

defined('ABSPATH') || die('error');

function gdprhelper__map_handler__entry(): void
{
    require_once(GH__PLUGIN_INCLUDES_PATH . '/includes/magicStrings.php');
    require_once(GH__PLUGIN_INCLUDES_PATH . '/includes/elementor/helper.php');

    add_action('elementor/widget/render_content',  'gdprhelper__map_handler__elementor_widget_render_content', 10, 2);
}

function gdprhelper__map_handler__elementor_widget_render_content($content, $obj)
{
    $content = '<span id=' . $obj->get_id() . '></span>' . $content;

    // Elementor - Google Maps Block
    $elementor_widget_class = get_class($obj);
    if ($elementor_widget_class == 'Elementor\Widget_Google_Maps' || $elementor_widget_class == 'OSM_Map\Widget_OSM_Map') {
        if (!$_COOKIE[GH__COOKIES__PRIVACY_POLICY_ACCEPTED]) {
            $settings = $obj->get_settings_for_display();

            $height = '200px';
            if ($settings['height']['size'] > 0) {
                $height = $settings['height']['size'] . $settings['height']['unit'];
            }

            gdprhelper__map_handler__show_placeholder_maps($content, $height, $obj->get_id());
        }
    }

    return $content;
}

function gdprhelper__map_handler__show_placeholder_maps(&$content, $map_height, $id_to_scroll_to)
{
    if (gdprhelper__helper__in_elementor_edit_mode()) {
        return;
    }

    $content = ''; // Reset content

    $options = get_option(GH__SETTINGS_PAGE__ID);

    // fallback if no placeholder image
    $image_src = GH__PLUGIN_URL . '/assets/map_default_placeholder.jpg';
    $image_id = $options[GH__SETTINGS_FIELDS__MAPS_PACEHOLDER_IMAGE];
    if ($image_id) {
        $image_src = wp_get_attachment_image_url($image_id, array('1920', '9999'));
    }

    $placeholder_header_text = __('Do you want to show this map? Doing so will lead to your personal data (your IP address) being sent to Google or OpenStreetMap, which can be used to track you.', GH__TEXT_DOMAIN);
    $privacy_policy_url =   $options[GH__SETTINGS_FIELDS__PRIVACY_URL];
    $accept_button_text = __('Show Map', GH__TEXT_DOMAIN);
    $image_height_with_unit = $map_height;
    $custom_text = $options[GH__SETTINGS_FIELDS__CUSTOM_PRIVACY_TEXT];

    $content = gdprhelper__helper__build_placeholder(
        $placeholder_header_text,
        $custom_text,
        $privacy_policy_url,
        $accept_button_text,
        $id_to_scroll_to,
        $image_src,
        $image_height_with_unit
    );

    return;
}
