<?php

defined('ABSPATH') || die('error');

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

function gdprhelper__custom_elementor__entry(): void
{
    require_once(GH__PLUGIN_INCLUDES_PATH . '/includes/magicStrings.php');
    require_once(GH__PLUGIN_INCLUDES_PATH . '/includes/elementor/helper.php');

    add_action('elementor/widgets/register', 'register_new_widgets');
}

function register_new_widgets($widgets_manager)
{
    $widgets_manager->register(new \GH_Shortcode_Widget());
}

class GH_Shortcode_Widget extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return GH__ELEMENTOR__SHORTCODE__NAME;
    }

    public function get_title()
    {
        return esc_html__('GDPR 2-click shortcode', GH__TEXT_DOMAIN);
    }

    public function get_icon()
    {
        return 'eicon-shortcode';
    }

    public function get_custom_help_url()
    {
        return 'https://xeas.at/kontakt/';
    }

    public function get_categories()
    {
        return ['general'];
    }

    public function get_keywords()
    {
        return ['gdpr', 'dsgvo', 'shortcode', 'helper', '2-click', 'click', 'code'];
    }

    /* ################## actual code ################## */
    /* ################## actual code ################## */
    /* ################## actual code ################## */

    public function is_reload_preview_required()
    {
        return true;
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'section_shortcode',
            [
                'label' => esc_html__('Shortcode', GH__TEXT_DOMAIN),
            ]
        );

        $this->add_control(
            GH__ELEMENTOR__SHORTCODE__CONTROL_SHORTCODE,
            [
                'label' => esc_html__('Enter your 2-click protected shortcode', GH__TEXT_DOMAIN),
                'type' => Controls_Manager::TEXTAREA,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => '[gallery id="123" size="medium"]',
                'default' => '',
            ]
        );

        $this->add_control(
            GH__ELEMENTOR__SHORTCODE__CONTROL_TEXT,
            [
                'label' => esc_html__('Enter the text to show instead of the shortcode', GH__TEXT_DOMAIN),
                'type' => Controls_Manager::TEXTAREA,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('This widget was blocked because it will request data from 3rd party providers. This can lead to your data being tracked. By showing this widget you accept our privacy policy.', GH__TEXT_DOMAIN),
                'default' => esc_html__('This widget was blocked because it will request data from 3rd party providers. This can lead to your data being tracked. By showing this widget you accept our privacy policy.', GH__TEXT_DOMAIN),
            ]
        );

        $this->add_control(
            GH__ELEMENTOR__SHORTCODE__CONTROL_HEIGHT,
            [
                'type' => \Elementor\Controls_Manager::SLIDER,
                'label' => esc_html__('Placeholder size', GH__TEXT_DOMAIN),
                'size_units' => ['px', 'vh'],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 1440,
                    ],
                    'vh' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 300,
                ],
            ]
        );

        $this->add_control(
            GH__ELEMENTOR__SHORTCODE__CONTROL_IMAGE,
            [
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label' => esc_html__('Choose placeholder Image', GH__TEXT_DOMAIN),
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $gh_options = get_option(GH__SETTINGS_PAGE__ID);
        $settings = $this->get_settings_for_display();

        $shortcode = $settings[GH__ELEMENTOR__SHORTCODE__CONTROL_SHORTCODE];
        $shortcode_content = do_shortcode(shortcode_unautop($shortcode));

        $placeholder_text = $settings[GH__ELEMENTOR__SHORTCODE__CONTROL_TEXT];
        $placeholder_height = $settings[GH__ELEMENTOR__SHORTCODE__CONTROL_HEIGHT]['size'] . $settings[GH__ELEMENTOR__SHORTCODE__CONTROL_HEIGHT]['unit'];
        $placeholder_image_url = $settings[GH__ELEMENTOR__SHORTCODE__CONTROL_IMAGE]['url'];

        $placeholder_header_text = __('Do you want to show this widget? Doing so will lead to your personal data (your IP address) being sent to 3rd party services, which can be used to track you.', GH__TEXT_DOMAIN);
        $privacy_policy_url =     $gh_options[GH__SETTINGS_FIELDS__PRIVACY_URL];
        $accept_button_text = __('Show Widget', GH__TEXT_DOMAIN);
        $image_src = $placeholder_image_url;
        $image_height_with_unit = $placeholder_height;
        $custom_text = $placeholder_text;
        $id_to_scroll_to = $this->get_id();

        $content = gdprhelper__helper__build_placeholder(
            $placeholder_header_text,
            $custom_text,
            $privacy_policy_url,
            $accept_button_text,
            $id_to_scroll_to,
            $image_src,
            $image_height_with_unit
        );

?>
        <div class="gh__shortcode-container">
            <?php
            if ($_COOKIE[GH__COOKIES__PRIVACY_POLICY_ACCEPTED] || gdprhelper__helper__in_elementor_edit_mode()) {
                echo $shortcode_content; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped 
            } else {
                echo $content; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped 
            }
            ?>
        </div>
<?php
    }

    public function render_plain_content()
    {
        // In plain mode, render without shortcode
        $this->print_unescaped_setting('shortcode');
    }
}
